@@ -1,15 +1,9 @@
-#  File R/zzz.R in package ergm.count, part of the Statnet suite
-#  of packages for network analysis, http://statnet.org .
-#
-#  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) at
-#  http://statnet.org/attribution
-#
-#  Copyright 2003-2013 Statnet Commons
-#######################################################################
 .onAttach <- function(lib, pkg){
   sm <- statnetStartupMessage("ergm.count",c("statnet"),FALSE)
-  if(!is.null(sm)) packageStartupMessage(sm)
+  if(!is.null(sm)){
+    packageStartupMessage(sm)
+    packageStartupMessage(paste(c(strwrap(paste("NOTE: The form of the term ",sQuote("CMP")," has been changed in version 3.2 of ",sQuote("ergm.count"),". See the news or help('CMP') for more information.",sep="")),""),collapse="\n"))
+  }
 
   .RegisterMHPs()
   .RegisterConstraintImplications()
@@ -18,6 +12,7 @@
 
 .RegisterMHPs <- function(){
   ergm.MHP.table("c", "Poisson", "",  0, "random", "Poisson")
+  ergm.MHP.table("c", "Poisson", "",  1, "TNT", "PoissonTNT")
   ergm.MHP.table("c", "Poisson", "",  0, "0inflated", "ZIPoisson")
   ergm.MHP.table("c", "Poisson", "observed",  0, "random", "PoissonNonObserved")
 
@@ -32,8 +27,7 @@
 }
 
 .RegisterInitMethods <- function(){
-  ergm.init.methods("Poisson", c("zeros"))
-  ergm.init.methods("Binomial", c("zeros"))
-  ergm.init.methods("Geometric", c("zeros"))
-  ergm.init.methods("DiscUnif", c("zeros"))
+  ergm.init.methods("Poisson", c("CD","zeros"))
+  ergm.init.methods("Binomial", c("CD","zeros"))
+  ergm.init.methods("Geometric", c("CD","zeros"))
 }
